# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_windows_management_deployment_preview

__all__ = [
    "ClassicAppManager",
    "InstalledClassicAppInfo",
]

ClassicAppManager = _winrt_windows_management_deployment_preview.ClassicAppManager
InstalledClassicAppInfo = _winrt_windows_management_deployment_preview.InstalledClassicAppInfo
